#
# spec file for package python-fake-useragent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-fake-useragent
Version:        1.5.1
Release:        1.2
Summary:        Useragent faker package for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/fake-useragent/fake-useragent
Source:         https://github.com/fake-useragent/fake-useragent/archive/refs/tags/%{version}.tar.gz#/fake-useragent-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-resources
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module importlib-resources >= 6.0.0}
BuildRequires:  %{python_module pytest >= 7.4.0}
# /SECTION
%python_subpackages

%description
Useragent faker with real world database.

%prep
%setup -q -n fake-useragent-%{version}
rm pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/fake[-_]useragent*/

%changelog
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.1:
  * Remove trailing spaces in user agent strings
- update to 1.5.0:
  * Most important change: The user-agent database has been
    updated with a more recent list of user agents. It also now
    comes with mobile UA's, meaning a new parameter: `platforms`
    has been introduced (see README.md).
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * python 3.12 support
  * Introducing new `ua.getRandom`, `ua.getFirefox`,
    `ua.getChrome`, `ua.getSafari`. And a generic method:
    `ua.getBrowser(..)` (eg. `getBrowser('firefox')`)
    These new properties above allows you to retrieve the whole
    raw Python dictionary, instead of only the UA string.
    These properties might return different key/values pairs in
    the future! So `ua.random` is a more stable interface.
  * Improved user-agent scraper (now also containing Safari
    browser again)
  * Updated browsers.json data file
* Tue Aug  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * Still using the new dataset of course!
  * Small improvements in the min_percentage check
  * Update all Pip package dependencies
  * Updated browser useragent data 🚀
  * Allow filters on browser, OS and usage percentage 🚀
  * Update the cache scraper to scape the new data source for
    user-agent strings
  * Adapted the code to work with the new JSON data format
* Wed Apr 19 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.3:
  * Update deps
* Thu Feb  9 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * security update
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * Remove white spaces from user agent strings, this is a patch release
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.1.0
  * Add pkg_resource as fallback mechanism in trying to retrieve the local JSON data file
* Fri Nov 18 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.0.1
  * Add importlib-metadata & importlib-resources as dependencies
  * Check on specific Python version regarding the importlib resources
    (python v3.10 or higher) in order to have files() working
  * importlib_metadata should now also work on Python version before 3.8
  * Remove obsolete MANIFEST.in file
- from v1.0.0
  * Make the JSON Lines data file part of the Python package,
    data is retrieved locally
  * Extend the myproject.toml file with package-data support
  * Remove centralized caching server implementation
  * Make real unit-tests which should run reliable, fast, independent
    and without Internet connection
- from v0.1.14
  * Improve code quality standards using modern Python >=3.7 syntax
  * Migrated to pyproject.toml build system format + syntax check
  * Add additional classifiers to the toml file
  * Improved tox.ini file
  * Improved GitHub Actions job using pip cache
  * And various small fixes
* Thu Nov  3 2022 John Vandenberg <jayvdb@gmail.com>
- Re-activate test suite
- Update to v0.1.13
  * Implement browsers argument, allowing you to override the browser
    names you want to use
  * Fix browser listing of Internet Explorer and Edge
  * Don't depend on w3schools.com anymore
  * Clean-up data (temp) file format
  * Update fallback cache server URL / use JSON Lines as file format
  * Move to GitHub Actions instead of Travis
  * Using black Python formatter in favour of Flake
- from v0.1.12
  * Project moved to https://github.com/fake-useragent/fake-useragent
* Wed Sep 15 2021 pgajdos@suse.com
- %%check: note tests are online, do not run them
* Thu Apr  4 2019 Todd R <toddrme2178@gmail.com>
- Initial version for v0.1.11
